# `perfect`
[![pypi](https://badge.fury.io/py/perfect.svg)](https://pypi.python.org/pypi/perfect/)
[![Made with Python](https://img.shields.io/pypi/pyversions/perfect)](https://www.python.org/)
[![Type hinted - mypy validated](https://img.shields.io/badge/typehinted-yes-teal)](https://github.com/kalaspuff/perfect)
[![MIT License](https://img.shields.io/github/license/kalaspuff/perfect.svg)](https://github.com/kalaspuff/perfect/blob/master/LICENSE)
[![Code coverage](https://codecov.io/gh/kalaspuff/perfect/branch/master/graph/badge.svg)](https://codecov.io/gh/kalaspuff/perfect/tree/master/perfect)

*A utility library which makes it simpler to create flexible decorators by just decorating them with the `@perfect` decorator.*


## Installation with `pip`
Like you would install any other Python package, use `pip`, `poetry`, `pipenv` or your weapon of choice.
```
$ pip install perfect
```


## Usage and examples

#### `@perfect` decorator
